%%
%% RCIarticle.cls version v1.0
%% Author: Jerick E. Ordenes Sepúlveda (os.jerick@gmail.com)
%% Copyright 2014 Universidad de Los Andes, Venezuela. Revista Ciencia e Ingeniería (revecien@ula.ve)
%% 				  University of the Andes, Venezuela. Science & Engineering Journal (revecien@ula.ve)
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%% 		http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% This work has the LPPL maintenance status `unmaintained'.
%% This work consists of the file RCIarticle.cls, RCIarticle_manual.pdf, RCIarticle_template.tex
%%

%% Modificado por Edgar Chacon para ajustarse a los nuevos requerimientos de la Revista Ciencia e Ingenier ía

\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{RCIarticle}
			  [2021/11/30 v1.01 LaTeX document class for multi authored article for the Science and Engineering Journal at the University of the Andes, Venezuela]
\typeout{-- See the "RCIarticle_manual.pdf" manual for usage information.}

%Load Packages
\RequirePackage[spanish,USenglish]{babel}
\newif\if@selectedspanish
\newif\if@loadpackages
\@loadpackagestrue
\newif\if@enablefancyheaders
\@enablefancyheaderstrue
%Declarations
\DeclareOption{spanish}{%
	\AtBeginDocument{\selectlanguage{spanish}}
	\gdef\@figurename{Fig.}
	\gdef\@tablename{Tabla}
	\@selectedspanishtrue
}
\DeclareOption{english}{%
	\AtBeginDocument{\selectlanguage{USenglish}}
	\gdef\@figurename{Fig.}
	\gdef\@tablename{Table}
	\@selectedspanishfalse
}
\DeclareOption{nopackages}{%
    \@loadpackagesfalse
    \@enablefancyheadersfalse
    \ClassWarningNoLine{RCIarticle}{Default packages are not loaded}
}
\DeclareOption{noheaders}{%
    \@enablefancyheadersfalse
    \ClassWarningNoLine{RCIarticle}{Document header and footer are disabled}
}
\DeclareOption*{\ClassWarningNoLine{RCIarticle}{Unknown `\CurrentOption', default language used is Spanish}}
\ExecuteOptions{spanish}
\ProcessOptions\relax

%Load Packages
\if@loadpackages
    \RequirePackage{fancyhdr}
    \RequirePackage{float}
    \RequirePackage[T1]{fontenc}
    \RequirePackage[utf8]{inputenc}
    \RequirePackage[fleqn]{amsmath}
\fi

\let\@afterindentfalse\@afterindenttrue
\@afterindenttrue

\@twosidetrue\@mparswitchtrue
\@twocolumntrue

\setlength{\paperheight}{11in}%
\setlength{\paperwidth}{8.5in}%
\setlength{\voffset}{-1in}%
\setlength{\hoffset}{-1in}%
\setlength{\textheight}{22.94cm}%
\setlength{\textwidth}{17.59cm}%
\setlength{\oddsidemargin}{2.5cm}%
\setlength{\evensidemargin}{2.5cm}%
\setlength{\headheight}{21mm}%
\setlength{\headsep}{4mm}%
\setlength{\columnsep}{0.5cm}%
\setlength{\footskip}{31pt}%
\setlength{\parindent}{0.7cm}%{3.5ex}%
\topsep=0\p@
\partopsep=0\p@
\topskip=12\p@
\setlength{\lineskip}{0\p@}
\setlength{\normallineskip}{0\p@}
\renewcommand{\baselinestretch}{}
\setlength{\footnotesep}{6.65\p@}
\setlength{\skip\footins}{9\p@ \@plus 4\p@ \@minus 2\p@}

%Set the document font size
\renewcommand{\normalsize}{\@setfontsize{\normalsize}{10pt}{12.00pt}%
\abovedisplayskip=1.5ex plus4pt minus2pt
\belowdisplayskip=\abovedisplayskip
\abovedisplayshortskip=0pt plus4pt
\belowdisplayshortskip=1.5ex plus4pt minus2pt
}
\normalsize
\newcommand{\tiny}{\@setfontsize{\tiny}{5pt}{6pt}}
\newcommand{\scriptsize}{\@setfontsize{\scriptsize}{7pt}{8pt}}
\newcommand{\footnotesize}{\@setfontsize{\footnotesize}{8pt}{9pt}}
\newcommand{\small}{\@setfontsize{\small}{9pt}{10pt}}
\newcommand{\large}{\@setfontsize{\large}{12pt}{14.4pt}}
\newcommand{\Large}{\@setfontsize{\Large}{14pt}{17.28pt}}
\newcommand{\LARGE}{\@setfontsize{\LARGE}{17.28pt}{23pt}}
\newcommand{\huge}{\@setfontsize{\huge}{20pt}{25pt}}
\newcommand{\Huge}{\@setfontsize{\Huge}{24pt}{29pt}}

\DeclareMathSizes{10.95}{10}{7}{7}
								
\def\@listi{\leftmargin\leftmargini \topsep 2pt plus 1pt minus 1pt}
\let\@listI\@listi
\def\@listii{\leftmargin\leftmarginii\labelwidth\leftmarginii%
    \advance\labelwidth-\labelsep \topsep 2pt}
\def\@listiii{\leftmargin\leftmarginiii\labelwidth\leftmarginiii%
    \advance\labelwidth-\labelsep \topsep 2pt}
\def\@listiv{\leftmargin\leftmarginiv\labelwidth\leftmarginiv%
    \advance\labelwidth-\labelsep \topsep 2pt}
\def\@listv{\leftmargin\leftmarginv\labelwidth\leftmarginv%
    \advance\labelwidth-\labelsep \topsep 2pt}
\def\@listvi{\leftmargin\leftmarginvi\labelwidth\leftmarginvi%
    \advance\labelwidth-\labelsep \topsep 2pt}

%Using Times Roman font
\renewcommand{\sfdefault}{phv}
\renewcommand{\rmdefault}{ptm}
\renewcommand{\ttdefault}{pcr}

%Tolerances
\hyphenpenalty=750
\hbadness=1350
\vbadness=1350

%Definition for floats
%%Normal floats
\floatsep 1\baselineskip plus  0.2\baselineskip minus  0.2\baselineskip
\textfloatsep 1.7\baselineskip plus  0.2\baselineskip minus  0.4\baselineskip
\@fptop 0pt plus 1fil
\@fpsep 0.75\baselineskip plus 2fil
\@fpbot 0pt plus 1fil
\def\topfraction{0.9}
\def\bottomfraction{0.4}
\def\floatpagefraction{0.8}
\def\textfraction{0.1}

%%Double Column Floats
\dblfloatsep 1\baselineskip plus  0.2\baselineskip minus  0.2\baselineskip
\dbltextfloatsep 1.7\baselineskip plus  0.2\baselineskip minus  0.4\baselineskip
\@dblfptop 0pt plus 1fil
\@dblfpsep 0.75\baselineskip plus 2fil
\@dblfpbot 0pt plus 1fil
\def\dbltopfraction{0.8}
\def\dblfloatpagefraction{0.8}
\setcounter{dbltopnumber}{4}
\intextsep 1\baselineskip plus 0.2\baselineskip minus  0.2\baselineskip
\setcounter{topnumber}{2}
\setcounter{bottomnumber}{2}
\setcounter{totalnumber}{4}

%Title
\def\title{\@dblarg\RCI@title}
\def\RCI@title[#1]#2#3{%
	\gdef\@maintitle{#2}%
    \gdef\@secondtitle{#3}%
	\gdef\@shorttitle{#1}
}
\def\@maintitle{\ClassWarningNoLine{RCIarticle}{Unknown main language title of the document}}
\def\@secondtitle{\ClassWarningNoLine{RCIarticle}{Unknown secondary language title of the document}}
\def\@shorttitle{}

%Authors
\newcommand{\affil}[1]{\ensuremath{{}^{\mbox{\normalfont\footnotesize#1}}}}

\def\shortauthors#1{\gdef\@shortauthors{#1}}
\def\@shortauthors{}

\def\author#1{\gdef\@author{#1}}
\def\@author{\ClassWarningNoLine{RCIarticle}{Unknown authors of the documents}}

%Affiliation
\newcommand{\affiliation}[1]{\gdef\@affiliation{#1}}
\def\@affiliation{}

%Email
\newcommand{\email}[1]{\gdef\@email{#1}}
\def\@email{}

%Keywords
\newcommand{\@spanishkeywordsname}{\noindent{\bfseries Palabras clave}}
\newcommand{\spanishkeywords}[1]{\gdef\@skeyw{\@spanishkeywordsname: #1.}}
\def\@skeyw{\ClassWarningNoLine{RCIarticle}{Unknown spanish key words}}

\newcommand{\@englishkeywordsname}{\noindent{\bfseries Key words}}
\newcommand{\englishkeywords}[1]{\gdef\@ekeyw{\@englishkeywordsname: #1.}}
\def\@ekeyw{\ClassWarningNoLine{RCIarticle}{Unknown english key words}}

%Abstracts
\newcommand{\@spanishabstractname}{Resumen}
\newcommand*{\spanishabstract}[1]{\gdef\@sabstract{#1}}

\newcommand{\@englishabstractname}{Abstract}
\newcommand*{\englishabstract}[1]{\gdef\@eabstract{#1}}

%Making Title
\def\linespace{\addvspace{\baselineskip}}
\newcommand{\maketitle}{\par
    \begingroup
    	\normalfont
    	\twocolumn[%
    	\if@enablefancyheaders\thispagestyle{firstpagestyle}\else\thispagestyle{empty}\fi\label{FirstPage}
    	\vspace{\baselineskip}
    	{\centering
    		{\bfseries
    			{\LARGE \@maintitle\par
    			\addvspace{14\p@}
                \if@selectedspanish
                    \foreignlanguage{USenglish}{\@secondtitle}\par
                \else
                    \foreignlanguage{spanish}{\@secondtitle}\par
                \fi
    			\addvspace{18\p@}}
    			\@author\par
    		}
    		\@affiliation\par
    		\@email\par
    		}
    		\addvspace{20\p@}
    		\if@selectedspanish
				\begin{otherlanguage}{spanish}
        		{\centering \bfseries \@spanishabstractname\par}%
        		\linespace
        		{\noindent\itshape\@sabstract\par}
        		\linespace
        		\@skeyw\par
				\end{otherlanguage}
        		\addvspace{20\p@}
				\begin{otherlanguage}{USenglish}
        		{\centering \bfseries \@englishabstractname\par}
        		\linespace
        		{\noindent\itshape\@eabstract\par}
        		\linespace
        		\@ekeyw\par
				\end{otherlanguage}
            \else
				\begin{otherlanguage}{USenglish}
                {\centering \bfseries \@englishabstractname\par}
        		\linespace
        		{\noindent\itshape\@eabstract\par}
        		\linespace
        		\@ekeyw\par
				\end{otherlanguage}
        		\addvspace{20\p@}
				\begin{otherlanguage}{spanish}
        		{\centering \bfseries \@spanishabstractname\par}%
        		\linespace%
        		{\noindent\itshape\@sabstract\par}
        		\linespace
        		\@skeyw\par
				\end{otherlanguage}
            \fi
            \vspace{2\baselineskip}
    		%\if@selectedspanish
    		%	\selectlanguage{spanish}
    		%\else
    		%	\selectlanguage{USenglish}
    		%\fi
    	]
        \suppressfloats[t]
    \endgroup
}

%Editor Tags
\newcommand{\received}[1]{\gdef\@received{\noindent{\itshape {\bfseries Recibido}: #1}}}
\def\@received{}
\newcommand{\accepted}[1]{\gdef\@accepted{\noindent{\itshape {\bfseries Aceptado}: #1}}}
\def\@accepted{}
\newcommand{\@makerredit}{%
	\par
	\vspace{2\baselineskip}
	\hspace{1.7cm}\@received\par
	\vspace*{\baselineskip}
	\hspace{2.5cm}\@accepted
}

\def\@volumenumber{??}
\newcommand*{\volumenumber}[1]{\def\@volumenumber{#1}}

\def\@editionnumber{??}
\newcommand*{\editionnumber}[1]{\def\@editionnumber{#1}}

\def\@volumemonths{????-????}
\newcommand*{\volumemonths}[1]{\def\@volumemonths{#1}}

\def\@volumeyear{\the\year}
\newcommand*{\volumeyear}[1]{\def\@volumeyear{#1}}

\def\@issnnumber{1316-7081}
\newcommand*{\issn}[1]{\def\@issnnumber{#1}}

\def\@issnelectnumber{2244-8780}
\newcommand*{\issnelect}[1]{\def\@issnelectnumber{#1}}


%Header And Footer
\def\@articletype{Artículo de Investigación}
\newcommand*{\articletype}[1]{\def\@articletype{#1}}

\def\@publicationname{Revista Ciencia e Ingeniería}
\newcommand*{\publicationname}[1]{\def\@publicationname{#1}}
\if@enablefancyheaders
    \fancypagestyle{firstpagestyle}{%
       \fancyhead{}
       \fancyhead[L]{}
       \fancyhead[R]{\itshape \@articletype. \@publicationname. Vol. \@volumenumber, No. \@editionnumber, pp. \pageref{FirstPage}-\pageref{LastPage}, \@volumemonths, \@volumeyear.\\
        ISSN \@issnnumber. ISSN Elect. \@issnelectnumber. Universidad de Los Andes (ULA)}
       \fancyfoot{}
       \fancyfoot[C]{\footnotesize \itshape \@publicationname. Vol. \@volumenumber, No. \@editionnumber, \@volumemonths, \@volumeyear}
       \renewcommand{\headrulewidth}{0.5pt}
       \renewcommand{\footrulewidth}{0.5pt}
    }
    \fancyhead{}
    \fancyhead[LE,RO]{\itshape \thepage}
    \fancyhead[RE]{\itshape \@shortauthors}
    \fancyhead[LO]{\itshape \@shorttitle}
    \fancyfoot{}
    \fancyfoot[C]{\footnotesize \itshape \@publicationname. Vol. \@volumenumber, No. \@editionnumber, \@volumemonths, \@volumeyear}
    \renewcommand{\headrulewidth}{0.5pt}
    \renewcommand{\footrulewidth}{0.5pt}
    \pagestyle{fancy}
\else
    \pagestyle{plain}
\fi
%Sections
\setcounter{secnumdepth}{3}
\newcounter {section}
\newcounter {subsection}[section]
\newcounter {subsubsection}[subsection]

\renewcommand\thesection{\@arabic\c@section}
\renewcommand\thesubsection{\thesection.\@arabic\c@subsection}
\renewcommand\thesubsubsection{\thesubsection.\@arabic\c@subsubsection}

\newcommand\section{\@startsection{section}{1}{\z@}%
                                   {3.0ex plus 1.5ex minus 1.5ex}%
                                   {0.7ex plus 1ex minus 0ex}%
                                   {\normalfont\normalsize\bfseries}}
\newcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {3.0ex plus 1.5ex minus 1.5ex}%
                                     {0.7ex plus .5ex minus 0ex}%
                                     {\normalfont\normalsize\itshape}}
\newcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {3.0ex plus 1.5ex minus 1.5ex}%
                                     {0.7ex plus .5ex minus 0ex}%
                                     {\normalfont\normalsize\itshape}}
\newcommand\paragraph{\@startsection{paragraph}{4}{2\parindent}%
                                    {0ex plus 0.1ex minus 0.1ex}%
                                    {0ex}%
                                    {\normalfont\normalsize\itshape}}%
									
%Lists
\itemindent \z@
\listparindent \z@
\setlength\leftmargini  {1.75em}
\leftmargin  \leftmargini
\leftmarginii       1em
\leftmarginiii    1.5em
\leftmarginiv     1.5em
\leftmarginv      1.0em
\leftmarginvi     1.0em
\labelsep         0.5em
\setlength  \labelwidth{\leftmargini}
\addtolength\labelwidth{-\labelsep}
\@beginparpenalty -\@lowpenalty
\@endparpenalty   -\@lowpenalty
\@itempenalty     -\@lowpenalty
\renewcommand\theenumi{\@arabic\c@enumi}
\renewcommand\theenumii{\@alph\c@enumii}
\renewcommand\theenumiii{\@roman\c@enumiii}
\renewcommand\theenumiv{\@Alph\c@enumiv}
\def\labelenumi{\theenumi)}
\def\labelenumii{\theenumii)}
\def\labelenumiii{\theenumiii)}
\def\labelenumiv{\theenumiv)}
\renewcommand\p@enumii{\theenumi}
\renewcommand\p@enumiii{\theenumi(\theenumii)}
\renewcommand\p@enumiv{\p@enumiii\theenumiii}
\def\labelitemi{\textbullet}
\def\labelitemii{$\circ$}
\def\labelitemiii{\textasteriskcentered}
\def\labelitemiv{\textbullet}
\newenvironment{description}
               {\list{}{\labelwidth\z@ \itemindent-\leftmargin
                        \let\makelabel\descriptionlabel}}
               {\endlist}
\newcommand*\descriptionlabel[1]{\hspace\labelsep
                                \normalfont\bfseries #1}

\renewcommand \theequation {\@arabic\c@equation}
\@ifpackagewith{amsmath}{fleqn}{\setlength{\mathindent}{0pt}}{}
								
%Figure and Table
\setlength\parskip{0\p@ \@plus \p@}
\setlength\arraycolsep{5\p@}
\setlength\tabcolsep{6\p@}
\setlength\arrayrulewidth{.4\p@}
\setlength\doublerulesep{2\p@}
\setlength\tabbingsep{\labelsep}
\skip\@mpfootins = \skip\footins
\setlength\fboxsep{3\p@}
\setlength\fboxrule{.4\p@}
\newcounter{figure}
\renewcommand \thefigure {\@arabic\c@figure}
\def\fps@figure{tbp}
\def\ftype@figure{1}
\def\ext@figure{lof}
\def\fnum@figure{\@figurename\nobreakspace\thefigure}
\newenvironment{figure}
               {\@float{figure}}
               {\end@float}
\newenvironment{figure*}
               {\@dblfloat{figure}}
               {\end@dblfloat}
\newcounter{table}
\renewcommand\thetable{\@arabic\c@table}
\def\fps@table{tbp}
\def\ftype@table{2}
\def\ext@table{lot}
\def\fnum@table{\@tablename\nobreakspace\thetable}
\newenvironment{table}
               {\@float{table}}
               {\end@float}
\newenvironment{table*}
               {\@dblfloat{table}}
               {\end@dblfloat}

\newlength\abovecaptionskip
\newlength\belowcaptionskip
\setlength\abovecaptionskip{8\p@}
\setlength\belowcaptionskip{8\p@}
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{{\footnotesize #1. #2}}%
  \ifdim \wd\@tempboxa >\hsize
    {\footnotesize #1. #2\par}
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

%Other Environments
\newenvironment{verse}
               {\let\\\@centercr
                \list{}{\itemsep      \z@
                        \itemindent   -1.5em%
                        \listparindent\itemindent
                        \rightmargin  \leftmargin
                        \advance\leftmargin 1.5em}%
                \item\relax}
               {\endlist}
\newenvironment{quotation}
               {\list{}{\listparindent 1.5em%
                        \itemindent    \listparindent
                        \rightmargin   \leftmargin
                        \parsep        \z@ \@plus\p@}%
                \item\relax}
               {\endlist}
\newenvironment{quote}
               {\list{}{\rightmargin\leftmargin}%
                \item\relax}
               {\endlist}

%Page numbering
\pagenumbering{arabic}
\newcommand{\initialpagenumber}[1]{\setcounter{page}{#1}}
								
%Old Font Commands
\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\@nomath\sl}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\@nomath\sc}
\DeclareRobustCommand*\cal{\@fontswitch\relax\mathcal}
\DeclareRobustCommand*\mit{\@fontswitch\relax\mathnormal}

%Table of contents
\newcommand\@pnumwidth{1.55em}
\newcommand\@tocrmarg{2.55em}
\newcommand\@dotsep{4.5}
\setcounter{tocdepth}{3}
\newcommand\tableofcontents{%
    \section*{\contentsname
        \@mkboth{%
           \MakeUppercase\contentsname}{\MakeUppercase\contentsname}}%
    \@starttoc{toc}%
    }
\newcommand*\l@section[2]{%
  \ifnum \c@tocdepth >\z@
    \addpenalty\@secpenalty
    \addvspace{1.0em \@plus\p@}%
    \setlength\@tempdima{1.5em}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      \leavevmode \bfseries
      \advance\leftskip\@tempdima
      \hskip -\leftskip
      #1\nobreak\hfil \nobreak\hb@xt@\@pnumwidth{\hss #2}\par
    \endgroup
  \fi}
\newcommand*\l@subsection{\@dottedtocline{2}{1.5em}{2.3em}}
\newcommand*\l@subsubsection{\@dottedtocline{3}{3.8em}{3.2em}}
\newcommand*\l@paragraph{\@dottedtocline{4}{7.0em}{4.1em}}
\newcommand*\l@subparagraph{\@dottedtocline{5}{10em}{5em}}
\newcommand\listoffigures{%
    \section*{\listfigurename}%
      \@mkboth{\MakeUppercase\listfigurename}%
              {\MakeUppercase\listfigurename}%
    \@starttoc{lof}%
    }
\newcommand*\l@figure{\@dottedtocline{1}{1.5em}{2.3em}}
\newcommand\listoftables{%
    \section*{\listtablename}%
      \@mkboth{%
          \MakeUppercase\listtablename}%
         {\MakeUppercase\listtablename}%
    \@starttoc{lot}%
    }
\let\l@table\l@figure

%Names
\if@selectedspanish
	\newcommand\refname{Referencias}
\else
	\newcommand\refname{References}
\fi

%The Bibliography
\newdimen\bibindent
\setlength\bibindent{-1.5em}
\newenvironment{thebibliography}[1]
     {\section*{\refname}%
      \@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\z@
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}
\newcommand\newblock{\hskip .11em\@plus.33em\@minus.07em}
\let\@openbib@code\@empty

%Footnotes
\renewcommand\footnoterule{%
  \kern-3\p@
  \hrule\@width.4\columnwidth
  \kern2.6\p@}
\newcommand\@makefntext[1]{%
    \parindent 1em%
    \noindent
    \hb@xt@1.8em{\hss\@makefnmark}#1}

%Biography
\newcommand{\name}[3]{\par\noindent {\bfseries #1:\ } #2 \\ \includegraphics[width=.3cm]{ORCiD_icon.jpg}\textbf{\url{https://orcid.org/#3}} \vspace{\baselineskip}}
\def\biography#1{\gdef\@makebiography{\vspace{2\baselineskip}\par \itshape #1}}
\def\@makebiography{\ClassWarningNoLine{RCIarticle}{Unknown author's biography}{unknown orcid}}

%Balance Columns
\newcommand{\columnbreak}{\linebreak[4]\newpage\noindent}

%At the end
\def\emptycleardoublepage{%
    \ifodd\c@page\newpage\hbox{}\newpage\thispagestyle{empty}\label{LastPage}\hbox{}\newpage%
    \else\label{LastPage}\fi%
}

\AtEndDocument{%
	\@makerredit
    \@makebiography
	\emptycleardoublepage
}
\pagenumbering{arabic}

\if@twocolumn
  \twocolumn
  \sloppy
  \flushbottom
\fi
\endinput
%End of the class
